pkglts\.option package
======================

Subpackages
-----------

.. toctree::

    pkglts.option.base
    pkglts.option.conda
    pkglts.option.coverage
    pkglts.option.coveralls
    pkglts.option.data
    pkglts.option.doc
    pkglts.option.flake8
    pkglts.option.git
    pkglts.option.github
    pkglts.option.gitlab
    pkglts.option.landscape
    pkglts.option.license
    pkglts.option.notebook
    pkglts.option.plugin_project
    pkglts.option.pypi
    pkglts.option.pysetup
    pkglts.option.readthedocs
    pkglts.option.requires
    pkglts.option.sphinx
    pkglts.option.test
    pkglts.option.tox
    pkglts.option.travis
    pkglts.option.version

Module contents
---------------

.. automodule:: pkglts.option
    :members:
    :undoc-members:
    :show-inheritance:
